# jothoma-DWWP.1

# Python Calculator 

Python Calculator is a sample calculator implemented using Python 3.7.

Python Calculator performs basic math operations, that is:

    addition
    multiplication
    division
    subtraction
    square root

## Installation

pip install Python-Calculator-by-John-Osilama

## How to Use Python Calculator 

The python calculator will ask you to enter a number between 1 - 5

entering 1 will call the add method of the calculator class;

entering 2 will call the subtract method of the calculator class;

entering 3 will call the multiply method of the calculator class;

entering 4 will call the divide method of the calculator class;

entering 5 will call the square root method of the calculator class;

After calculation is completed, the python calculator will reset and start again

## About the Author

Hi, my name is John Osilama Thomas. I'm a Python Developer


## License 

Python Calculator is released under the MIT License.
